==> zio-streams-compress-zstd_3-0.0.1-javadoc.jar: scripts/searchData.js <==
pages = [{"l":"index.html#","e":false,"i":"","n":"zio-streams-compress-zstd","t":"zio-streams-compress-zstd","d":"","k":"static","x":""},
{"l":"zio/compress.html#","e":false,"i":"","n":"zio.compress","t":"zio.compress","d":"","k":"package","x":""},
{"l":"zio/compress/ZstdCompressionLevel.html#","e":false,"i":"","n":"ZstdCompressionLevel","t":"ZstdCompressionLevel","d":"zio.compress","k":"class","x":""},
{"l":"zio/compress/ZstdCompressionLevel$.html#","e":false,"i":"","n":"ZstdCompressionLevel","t":"ZstdCompressionLevel","d":"zio.compress","k":"object","x":""},
{"l":"zio/compress/ZstdCompressionLevel$.html#CompressionLevel1-0","e":false,"i":"","n":"CompressionLevel1","t":"CompressionLevel1: ZstdCompressionLevel","d":"zio.compress.ZstdCompressionLevel","k":"val","x":""},
{"l":"zio/compress/ZstdCompressionLevel$.html#CompressionLevel10-0","e":false,"i":"","n":"CompressionLevel10","t":"CompressionLevel10: ZstdCompressionLevel","d":"zio.compress.ZstdCompressionLevel","k":"val","x":""},
{"l":"zio/compress/ZstdCompressionLevel$.html#CompressionLevel11-0","e":false,"i":"","n":"CompressionLevel11","t":"CompressionLevel11: ZstdCompressionLevel","d":"zio.compress.ZstdCompressionLevel","k":"val","x":""},
{"l":"zio/compress/ZstdCompressionLevel$.html#CompressionLevel12-0","e":false,"i":"","n":"CompressionLevel12","t":"CompressionLevel12: ZstdCompressionLevel","d":"zio.compress.ZstdCompressionLevel","k":"val","x":""},
{"l":"zio/compress/ZstdCompressionLevel$.html#CompressionLevel13-0","e":false,"i":"","n":"CompressionLevel13","t":"CompressionLevel13: ZstdCompressionLevel","d":"zio.compress.ZstdCompressionLevel","k":"val","x":""},
{"l":"zio/compress/ZstdCompressionLevel$.html#CompressionLevel14-0","e":false,"i":"","n":"CompressionLevel14","t":"CompressionLevel14: ZstdCompressionLevel","d":"zio.compress.ZstdCompressionLevel","k":"val","x":""},
{"l":"zio/compress/ZstdCompressionLevel$.html#CompressionLevel15-0","e":false,"i":"","n":"CompressionLevel15","t":"CompressionLevel15: ZstdCompressionLevel","d":"zio.compress.ZstdCompressionLevel","k":"val","x":""},
{"l":"zio/compress/ZstdCompressionLevel$.html#CompressionLevel16-0","e":false,"i":"","n":"CompressionLevel16","t":"CompressionLevel16: ZstdCompressionLevel","d":"zio.compress.ZstdCompressionLevel","k":"val","x":""},
{"l":"zio/compress/ZstdCompressionLevel$.html#CompressionLevel17-0","e":false,"i":"","n":"CompressionLevel17","t":"CompressionLevel17: ZstdCompressionLevel","d":"zio.compress.ZstdCompressionLevel","k":"val","x":""},
{"l":"zio/compress/ZstdCompressionLevel$.html#CompressionLevel18-0","e":false,"i":"","n":"CompressionLevel18","t":"CompressionLevel18: ZstdCompressionLevel","d":"zio.compress.ZstdCompressionLevel","k":"val","x":""},
{"l":"zio/compress/ZstdCompressionLevel$.html#CompressionLevel19-0","e":false,"i":"","n":"CompressionLevel19","t":"CompressionLevel19: ZstdCompressionLevel","d":"zio.compress.ZstdCompressionLevel","k":"val","x":""},
{"l":"zio/compress/ZstdCompressionLevel$.html#CompressionLevel2-0","e":false,"i":"","n":"CompressionLevel2","t":"CompressionLevel2: ZstdCompressionLevel","d":"zio.compress.ZstdCompressionLevel","k":"val","x":""},
{"l":"zio/compress/ZstdCompressionLevel$.html#CompressionLevel3-0","e":false,"i":"","n":"CompressionLevel3","t":"CompressionLevel3: ZstdCompressionLevel","d":"zio.compress.ZstdCompressionLevel","k":"val","x":""},
{"l":"zio/compress/ZstdCompressionLevel$.html#CompressionLevel4-0","e":false,"i":"","n":"CompressionLevel4","t":"CompressionLevel4: ZstdCompressionLevel","d":"zio.compress.ZstdCompressionLevel","k":"val","x":""},
{"l":"zio/compress/ZstdCompressionLevel$.html#CompressionLevel5-0","e":false,"i":"","n":"CompressionLevel5","t":"CompressionLevel5: ZstdCompressionLevel","d":"zio.compress.ZstdCompressionLevel","k":"val","x":""},
{"l":"zio/compress/ZstdCompressionLevel$.html#CompressionLevel6-0","e":false,"i":"","n":"CompressionLevel6","t":"CompressionLevel6: ZstdCompressionLevel","d":"zio.compress.ZstdCompressionLevel","k":"val","x":""},
{"l":"zio/compress/ZstdCompressionLevel$.html#CompressionLevel7-0","e":false,"i":"","n":"CompressionLevel7","t":"CompressionLevel7: ZstdCompressionLevel","d":"zio.compress.ZstdCompressionLevel","k":"val","x":""},
{"l":"zio/compress/ZstdCompressionLevel$.html#CompressionLevel8-0","e":false,"i":"","n":"CompressionLevel8","t":"CompressionLevel8: ZstdCompressionLevel","d":"zio.compress.ZstdCompressionLevel","k":"val","x":""},
{"l":"zio/compress/ZstdCompressionLevel$.html#CompressionLevel9-0","e":false,"i":"","n":"CompressionLevel9","t":"CompressionLevel9: ZstdCompressionLevel","d":"zio.compress.ZstdCompressionLevel","k":"val","x":""},
{"l":"zio/compress/ZstdCompressionLevel$.html#CompressionLevelFast0-0","e":false,"i":"","n":"CompressionLevelFast0","t":"CompressionLevelFast0: ZstdCompressionLevel","d":"zio.compress.ZstdCompressionLevel","k":"val","x":""},
{"l":"zio/compress/ZstdCompressionLevel$.html#CompressionLevelFast1-0","e":false,"i":"","n":"CompressionLevelFast1","t":"CompressionLevelFast1: ZstdCompressionLevel","d":"zio.compress.ZstdCompressionLevel","k":"val","x":""},
{"l":"zio/compress/ZstdCompressionLevel$.html#CompressionLevelFast2-0","e":false,"i":"","n":"CompressionLevelFast2","t":"CompressionLevelFast2: ZstdCompressionLevel","d":"zio.compress.ZstdCompressionLevel","k":"val","x":""},
{"l":"zio/compress/ZstdCompressionLevel$.html#CompressionLevelFast3-0","e":false,"i":"","n":"CompressionLevelFast3","t":"CompressionLevelFast3: ZstdCompressionLevel","d":"zio.compress.ZstdCompressionLevel","k":"val","x":""},
{"l":"zio/compress/ZstdCompressionLevel$.html#CompressionLevelFast4-0","e":false,"i":"","n":"CompressionLevelFast4","t":"CompressionLevelFast4: ZstdCompressionLevel","d":"zio.compress.ZstdCompressionLevel","k":"val","x":""},
{"l":"zio/compress/ZstdCompressionLevel$.html#CompressionLevelFast5-0","e":false,"i":"","n":"CompressionLevelFast5","t":"CompressionLevelFast5: ZstdCompressionLevel","d":"zio.compress.ZstdCompressionLevel","k":"val","x":""},
{"l":"zio/compress/ZstdCompressionLevel$.html#CompressionLevelFast6-0","e":false,"i":"","n":"CompressionLevelFast6","t":"CompressionLevelFast6: ZstdCompressionLevel","d":"zio.compress.ZstdCompressionLevel","k":"val","x":""},
{"l":"zio/compress/ZstdCompressionLevel$.html#CompressionLevelFast7-0","e":false,"i":"","n":"CompressionLevelFast7","t":"CompressionLevelFast7: ZstdCompressionLevel","d":"zio.compress.ZstdCompressionLevel","k":"val","x":""},
{"l":"zio/compress/ZstdCompressionLevel$.html#CompressionLevelUltra20-0","e":false,"i":"","n":"CompressionLevelUltra20","t":"CompressionLevelUltra20: ZstdCompressionLevel","d":"zio.compress.ZstdCompressionLevel","k":"val","x":""},
{"l":"zio/compress/ZstdCompressionLevel$.html#CompressionLevelUltra21-0","e":false,"i":"","n":"CompressionLevelUltra21","t":"CompressionLevelUltra21: ZstdCompressionLevel","d":"zio.compress.ZstdCompressionLevel","k":"val","x":""},
{"l":"zio/compress/ZstdCompressionLevel$.html#CompressionLevelUltra22-0","e":false,"i":"","n":"CompressionLevelUltra22","t":"CompressionLevelUltra22: ZstdCompressionLevel","d":"zio.compress.ZstdCompressionLevel","k":"val","x":""},
{"l":"zio/compress/ZstdCompressionLevel$.html#DefaultCompressionLevel-0","e":false,"i":"","n":"DefaultCompressionLevel","t":"DefaultCompressionLevel: ZstdCompressionLevel","d":"zio.compress.ZstdCompressionLevel","k":"val","x":""},
{"l":"zio/compress/ZstdCompressionLevel$.html#FastCompressionLevel-0","e":false,"i":"","n":"FastCompressionLevel","t":"FastCompressionLevel: ZstdCompressionLevel","d":"zio.compress.ZstdCompressionLevel","k":"val","x":""},
{"l":"zio/compress/ZstdCompressionLevel$.html#HighCompressionLevel-0","e":false,"i":"","n":"HighCompressionLevel","t":"HighCompressionLevel: ZstdCompressionLevel","d":"zio.compress.ZstdCompressionLevel","k":"val","x":""},
{"l":"zio/compress/ZstdCompressionLevel$.html#UltraCompressionLevel-0","e":false,"i":"","n":"UltraCompressionLevel","t":"UltraCompressionLevel: ZstdCompressionLevel","d":"zio.compress.ZstdCompressionLevel","k":"val","x":""},
{"l":"zio/compress/ZstdCompressionLevel$.html#VeryHighCompressionLevel-0","e":false,"i":"","n":"VeryHighCompressionLevel","t":"VeryHighCompressionLevel: ZstdCompressionLevel","d":"zio.compress.ZstdCompressionLevel","k":"val","x":""},
{"l":"zio/compress/ZstdCompressionLevel$.html#apply-fffff2e4","e":false,"i":"","n":"apply","t":"apply(level: Int): Option[ZstdCompressionLevel]","d":"zio.compress.ZstdCompressionLevel","k":"def","x":""},
{"l":"zio/compress/ZstdCompressor$.html#","e":false,"i":"","n":"ZstdCompressor","t":"ZstdCompressor","d":"zio.compress","k":"object","x":""},
{"l":"zio/compress/ZstdCompressor$.html#make-fffff1d5","e":false,"i":"","n":"make","t":"make(level: Option[ZstdCompressionLevel], workers: Option[Int], customDictionary: Option[Array[Byte]]): ZstdCompressor","d":"zio.compress.ZstdCompressor","k":"def","x":""},
{"l":"zio/compress/ZstdCompressor.html#","e":false,"i":"","n":"ZstdCompressor","t":"ZstdCompressor extends Compressor","d":"zio.compress","k":"class","x":""},
{"l":"zio/compress/ZstdDecompressor$.html#","e":false,"i":"","n":"ZstdDecompressor","t":"ZstdDecompressor","d":"zio.compress","k":"object","x":""},
{"l":"zio/compress/ZstdDecompressor$.html#make-c26","e":false,"i":"","n":"make","t":"make(chunkSize: Int): ZstdDecompressor","d":"zio.compress.ZstdDecompressor","k":"def","x":""},
{"l":"zio/compress/ZstdDecompressor.html#","e":false,"i":"","n":"ZstdDecompressor","t":"ZstdDecompressor extends Decompressor","d":"zio.compress","k":"class","x":""}];

==> zio-streams-compress-zstd_3-1.0.0-javadoc.jar: scripts/searchData.js <==
pages = [{"l":"index.html#","e":false,"i":"","n":"zio-streams-compress-zstd","t":"zio-streams-compress-zstd","d":"","k":"static","x":""},
{"l":"zio/compress.html#","e":false,"i":"","n":"zio.compress","t":"zio.compress","d":"","k":"package","x":""},
{"l":"zio/compress/ZstdCompressionLevel.html#","e":false,"i":"","n":"ZstdCompressionLevel","t":"ZstdCompressionLevel extends AnyVal","d":"zio.compress","k":"class","x":""},
{"l":"zio/compress/ZstdCompressionLevel$.html#","e":false,"i":"","n":"ZstdCompressionLevel","t":"ZstdCompressionLevel","d":"zio.compress","k":"object","x":""},
{"l":"zio/compress/ZstdCompressionLevel$.html#CompressionLevel1-0","e":false,"i":"","n":"CompressionLevel1","t":"CompressionLevel1: ZstdCompressionLevel","d":"zio.compress.ZstdCompressionLevel","k":"val","x":""},
{"l":"zio/compress/ZstdCompressionLevel$.html#CompressionLevel10-0","e":false,"i":"","n":"CompressionLevel10","t":"CompressionLevel10: ZstdCompressionLevel","d":"zio.compress.ZstdCompressionLevel","k":"val","x":""},
{"l":"zio/compress/ZstdCompressionLevel$.html#CompressionLevel11-0","e":false,"i":"","n":"CompressionLevel11","t":"CompressionLevel11: ZstdCompressionLevel","d":"zio.compress.ZstdCompressionLevel","k":"val","x":""},
{"l":"zio/compress/ZstdCompressionLevel$.html#CompressionLevel12-0","e":false,"i":"","n":"CompressionLevel12","t":"CompressionLevel12: ZstdCompressionLevel","d":"zio.compress.ZstdCompressionLevel","k":"val","x":""},
{"l":"zio/compress/ZstdCompressionLevel$.html#CompressionLevel13-0","e":false,"i":"","n":"CompressionLevel13","t":"CompressionLevel13: ZstdCompressionLevel","d":"zio.compress.ZstdCompressionLevel","k":"val","x":""},
{"l":"zio/compress/ZstdCompressionLevel$.html#CompressionLevel14-0","e":false,"i":"","n":"CompressionLevel14","t":"CompressionLevel14: ZstdCompressionLevel","d":"zio.compress.ZstdCompressionLevel","k":"val","x":""},
{"l":"zio/compress/ZstdCompressionLevel$.html#CompressionLevel15-0","e":false,"i":"","n":"CompressionLevel15","t":"CompressionLevel15: ZstdCompressionLevel","d":"zio.compress.ZstdCompressionLevel","k":"val","x":""},
{"l":"zio/compress/ZstdCompressionLevel$.html#CompressionLevel16-0","e":false,"i":"","n":"CompressionLevel16","t":"CompressionLevel16: ZstdCompressionLevel","d":"zio.compress.ZstdCompressionLevel","k":"val","x":""},
{"l":"zio/compress/ZstdCompressionLevel$.html#CompressionLevel17-0","e":false,"i":"","n":"CompressionLevel17","t":"CompressionLevel17: ZstdCompressionLevel","d":"zio.compress.ZstdCompressionLevel","k":"val","x":""},
{"l":"zio/compress/ZstdCompressionLevel$.html#CompressionLevel18-0","e":false,"i":"","n":"CompressionLevel18","t":"CompressionLevel18: ZstdCompressionLevel","d":"zio.compress.ZstdCompressionLevel","k":"val","x":""},
{"l":"zio/compress/ZstdCompressionLevel$.html#CompressionLevel19-0","e":false,"i":"","n":"CompressionLevel19","t":"CompressionLevel19: ZstdCompressionLevel","d":"zio.compress.ZstdCompressionLevel","k":"val","x":""},
{"l":"zio/compress/ZstdCompressionLevel$.html#CompressionLevel2-0","e":false,"i":"","n":"CompressionLevel2","t":"CompressionLevel2: ZstdCompressionLevel","d":"zio.compress.ZstdCompressionLevel","k":"val","x":""},
{"l":"zio/compress/ZstdCompressionLevel$.html#CompressionLevel3-0","e":false,"i":"","n":"CompressionLevel3","t":"CompressionLevel3: ZstdCompressionLevel","d":"zio.compress.ZstdCompressionLevel","k":"val","x":""},
{"l":"zio/compress/ZstdCompressionLevel$.html#CompressionLevel4-0","e":false,"i":"","n":"CompressionLevel4","t":"CompressionLevel4: ZstdCompressionLevel","d":"zio.compress.ZstdCompressionLevel","k":"val","x":""},
{"l":"zio/compress/ZstdCompressionLevel$.html#CompressionLevel5-0","e":false,"i":"","n":"CompressionLevel5","t":"CompressionLevel5: ZstdCompressionLevel","d":"zio.compress.ZstdCompressionLevel","k":"val","x":""},
{"l":"zio/compress/ZstdCompressionLevel$.html#CompressionLevel6-0","e":false,"i":"","n":"CompressionLevel6","t":"CompressionLevel6: ZstdCompressionLevel","d":"zio.compress.ZstdCompressionLevel","k":"val","x":""},
{"l":"zio/compress/ZstdCompressionLevel$.html#CompressionLevel7-0","e":false,"i":"","n":"CompressionLevel7","t":"CompressionLevel7: ZstdCompressionLevel","d":"zio.compress.ZstdCompressionLevel","k":"val","x":""},
{"l":"zio/compress/ZstdCompressionLevel$.html#CompressionLevel8-0","e":false,"i":"","n":"CompressionLevel8","t":"CompressionLevel8: ZstdCompressionLevel","d":"zio.compress.ZstdCompressionLevel","k":"val","x":""},
{"l":"zio/compress/ZstdCompressionLevel$.html#CompressionLevel9-0","e":false,"i":"","n":"CompressionLevel9","t":"CompressionLevel9: ZstdCompressionLevel","d":"zio.compress.ZstdCompressionLevel","k":"val","x":""},
{"l":"zio/compress/ZstdCompressionLevel$.html#CompressionLevelFast0-0","e":false,"i":"","n":"CompressionLevelFast0","t":"CompressionLevelFast0: ZstdCompressionLevel","d":"zio.compress.ZstdCompressionLevel","k":"val","x":""},
{"l":"zio/compress/ZstdCompressionLevel$.html#CompressionLevelFast1-0","e":false,"i":"","n":"CompressionLevelFast1","t":"CompressionLevelFast1: ZstdCompressionLevel","d":"zio.compress.ZstdCompressionLevel","k":"val","x":""},
{"l":"zio/compress/ZstdCompressionLevel$.html#CompressionLevelFast2-0","e":false,"i":"","n":"CompressionLevelFast2","t":"CompressionLevelFast2: ZstdCompressionLevel","d":"zio.compress.ZstdCompressionLevel","k":"val","x":""},
{"l":"zio/compress/ZstdCompressionLevel$.html#CompressionLevelFast3-0","e":false,"i":"","n":"CompressionLevelFast3","t":"CompressionLevelFast3: ZstdCompressionLevel","d":"zio.compress.ZstdCompressionLevel","k":"val","x":""},
{"l":"zio/compress/ZstdCompressionLevel$.html#CompressionLevelFast4-0","e":false,"i":"","n":"CompressionLevelFast4","t":"CompressionLevelFast4: ZstdCompressionLevel","d":"zio.compress.ZstdCompressionLevel","k":"val","x":""},
{"l":"zio/compress/ZstdCompressionLevel$.html#CompressionLevelFast5-0","e":false,"i":"","n":"CompressionLevelFast5","t":"CompressionLevelFast5: ZstdCompressionLevel","d":"zio.compress.ZstdCompressionLevel","k":"val","x":""},
{"l":"zio/compress/ZstdCompressionLevel$.html#CompressionLevelFast6-0","e":false,"i":"","n":"CompressionLevelFast6","t":"CompressionLevelFast6: ZstdCompressionLevel","d":"zio.compress.ZstdCompressionLevel","k":"val","x":""},
{"l":"zio/compress/ZstdCompressionLevel$.html#CompressionLevelFast7-0","e":false,"i":"","n":"CompressionLevelFast7","t":"CompressionLevelFast7: ZstdCompressionLevel","d":"zio.compress.ZstdCompressionLevel","k":"val","x":""},
{"l":"zio/compress/ZstdCompressionLevel$.html#CompressionLevelUltra20-0","e":false,"i":"","n":"CompressionLevelUltra20","t":"CompressionLevelUltra20: ZstdCompressionLevel","d":"zio.compress.ZstdCompressionLevel","k":"val","x":""},
{"l":"zio/compress/ZstdCompressionLevel$.html#CompressionLevelUltra21-0","e":false,"i":"","n":"CompressionLevelUltra21","t":"CompressionLevelUltra21: ZstdCompressionLevel","d":"zio.compress.ZstdCompressionLevel","k":"val","x":""},
{"l":"zio/compress/ZstdCompressionLevel$.html#CompressionLevelUltra22-0","e":false,"i":"","n":"CompressionLevelUltra22","t":"CompressionLevelUltra22: ZstdCompressionLevel","d":"zio.compress.ZstdCompressionLevel","k":"val","x":""},
{"l":"zio/compress/ZstdCompressionLevel$.html#DefaultCompressionLevel-0","e":false,"i":"","n":"DefaultCompressionLevel","t":"DefaultCompressionLevel: ZstdCompressionLevel","d":"zio.compress.ZstdCompressionLevel","k":"val","x":""},
{"l":"zio/compress/ZstdCompressionLevel$.html#FastCompressionLevel-0","e":false,"i":"","n":"FastCompressionLevel","t":"FastCompressionLevel: ZstdCompressionLevel","d":"zio.compress.ZstdCompressionLevel","k":"val","x":""},
{"l":"zio/compress/ZstdCompressionLevel$.html#HighCompressionLevel-0","e":false,"i":"","n":"HighCompressionLevel","t":"HighCompressionLevel: ZstdCompressionLevel","d":"zio.compress.ZstdCompressionLevel","k":"val","x":""},
{"l":"zio/compress/ZstdCompressionLevel$.html#UltraCompressionLevel-0","e":false,"i":"","n":"UltraCompressionLevel","t":"UltraCompressionLevel: ZstdCompressionLevel","d":"zio.compress.ZstdCompressionLevel","k":"val","x":""},
{"l":"zio/compress/ZstdCompressionLevel$.html#VeryHighCompressionLevel-0","e":false,"i":"","n":"VeryHighCompressionLevel","t":"VeryHighCompressionLevel: ZstdCompressionLevel","d":"zio.compress.ZstdCompressionLevel","k":"val","x":""},
{"l":"zio/compress/ZstdCompressionLevel$.html#apply-fffff2e4","e":false,"i":"","n":"apply","t":"apply(level: Int): Option[ZstdCompressionLevel]","d":"zio.compress.ZstdCompressionLevel","k":"def","x":""},
{"l":"zio/compress/ZstdCompressor$.html#","e":false,"i":"","n":"ZstdCompressor","t":"ZstdCompressor","d":"zio.compress","k":"object","x":""},
{"l":"zio/compress/ZstdCompressor$.html#apply-fffff1d5","e":false,"i":"","n":"apply","t":"apply(level: Option[ZstdCompressionLevel], workers: Option[Int], customDictionary: Option[Array[Byte]]): ZstdCompressor","d":"zio.compress.ZstdCompressor","k":"def","x":""},
{"l":"zio/compress/ZstdCompressor$.html#compress-0","e":false,"i":"","n":"compress","t":"compress: ZPipeline[Any, Throwable, Byte, Byte]","d":"zio.compress.ZstdCompressor","k":"def","x":""},
{"l":"zio/compress/ZstdCompressor.html#","e":false,"i":"","n":"ZstdCompressor","t":"ZstdCompressor extends Compressor","d":"zio.compress","k":"class","x":""},
{"l":"zio/compress/ZstdDecompressor$.html#","e":false,"i":"","n":"ZstdDecompressor","t":"ZstdDecompressor","d":"zio.compress","k":"object","x":""},
{"l":"zio/compress/ZstdDecompressor$.html#apply-c26","e":false,"i":"","n":"apply","t":"apply(chunkSize: Int): ZstdDecompressor","d":"zio.compress.ZstdDecompressor","k":"def","x":""},
{"l":"zio/compress/ZstdDecompressor$.html#decompress-0","e":false,"i":"","n":"decompress","t":"decompress: ZPipeline[Any, Throwable, Byte, Byte]","d":"zio.compress.ZstdDecompressor","k":"def","x":""},
{"l":"zio/compress/ZstdDecompressor.html#","e":false,"i":"","n":"ZstdDecompressor","t":"ZstdDecompressor extends Decompressor","d":"zio.compress","k":"class","x":""}];
